@@ -35,7 +35,7 @@
 #' augment(gravity, trade)
 #'
 #' ## To get robust or clustered SEs, users can either:
-#  # 1) Or, specify the arguments directly in the tidy() call
+#' # 1) Or, specify the arguments directly in the tidy() call
 #' tidy(gravity, conf.int = TRUE, cluster = c("Product", "Year"))
 #' tidy(gravity, conf.int = TRUE, se = "threeway")
 #' # 2) Feed tidy() a summary.fixest object that has already accepted these arguments
@@ -55,60 +55,6 @@
 #' @seealso [tidy()], [fixest::feglm()], [fixest::fenegbin()],
 #' [fixest::feNmlm()], [fixest::femlm()], [fixest::feols()], [fixest::fepois()]
 tidy.fixest <- function(x, conf.int = FALSE, conf.level = 0.95, ...) {
-  not_summary <- !is_fixest_summary(x)
-  # These two options are necessary because the user might specify
-  # broom(x, cluster="something") or
-  # broom(summary(x, cluster="something"))
-  # and calling summary() again will overwrite the arguments in the second case.
-  # Note that class(summary(x)) == class(x) == "fixest".
-  if (not_summary) {
-    # Option 1) User provides a non-summary object
-    ret <- tidy_fixest(x, conf.int = conf.int, conf.level = conf.level, ...)
-  } else {
-    # Option 2) User provides a fixest summary object
-    ret <- tidy_summary_fixest(x, conf.int = conf.int, conf.level = conf.level)
-  }
-  as_tibble(ret)
-}
-
-is_fixest_summary <- function(x) {
-  # Is `x` the result of summary(some_fixest_result)?
-  # Returns TRUE/FALSE.
-  if (!inherits(x, "fixest")) {
-    stop("This is a fixest helper function only.")
-  }
-  "cov.scaled" %in% names(x)
-}
-
-tidy_summary_fixest <- function(x, conf.int = conf.int, conf.level = conf.level, ...) {
-  # If this is a summary object, assume the user has already applied whatever
-  # clustering or standard error specification they want.
-  if (length(list(...)) > 0) {
-    stop(
-      "The fixest object provided to tidy() was already a summary. ",
-      "Additional arguments were provided but can't be used. ",
-      "To specify `cluster` or `se`, call tidy() without summary()."
-    )
-  }
-  coeftable <- x$coeftable
-  ret <- as_tibble(coeftable, rownames = "term")
-  colnames(ret) <- c("term", "estimate", "std.error", "statistic", "p.value")
-
-  if (conf.int) {
-    # It's possible we were passed a summary of a fixest object. If no `...`
-    # arguments were specified, then we want to use the std error that `x`
-    # already has. That is, we don't want to call confint() because
-    # doing so throws away whatever arguments were provided to summary().
-    ci_fact <- abs(qnorm((1 - conf.level) / 2))
-    ret <- mutate(ret,
-      conf.low  = estimate - ci_fact * std.error,
-      conf.high = estimate + ci_fact * std.error
-    )
-  }
-  ret
-}
-
-tidy_fixest <- function(x, conf.int = conf.int, conf.level = conf.level, ...) {
   coeftable <- summary(x, ...)$coeftable
   ret <- as_tibble(coeftable, rownames = "term")
   colnames(ret) <- c("term", "estimate", "std.error", "statistic", "p.value")
@@ -118,11 +64,10 @@ tidy_fixest <- function(x, conf.int = conf.int, conf.level = conf.level, ...) {
     colnames(CI) <- c("conf.low", "conf.high")
     ret <- bind_cols(ret, unrowname(CI))
   }
-  ret
+  as_tibble(ret)
 }
 
 
-
 #' @templateVar class fixest
 #' @template title_desc_augment
 #'
@@ -130,8 +75,10 @@ tidy_fixest <- function(x, conf.int = conf.int, conf.level = conf.level, ...) {
 #' @template param_data
 #' @template param_newdata
 #' @param type.predict Passed to [`predict.fixest`][fixest::predict.fixest()]
-#'   `type` argument. Defaults to `"link"` (like `glm.predict`).
-#'
+#'   `type` argument. Defaults to `"link"` (like `predict.glm`).
+#' @param type.residuals Passed to [`predict.fixest`][fixest::residuals.fixest()]
+#'   `type` argument. Defaults to `"response"` (like `residuals.lm`, but unlike
+#'   `residuals.glm`).
 #' @evalRd return_augment()
 #'
 #' @note Important note: `fixest` models do not include a copy of the input
@@ -143,14 +90,18 @@ tidy_fixest <- function(x, conf.int = conf.int, conf.level = conf.level, ...) {
 #' @export
 #' @family fixest tidiers
 #' @seealso [augment()], [fixest::feglm()], [fixest::femlm()], [fixest::feols()]
-augment.fixest <- function(x, data = NULL, newdata = NULL, 
-                           type.predict = "response", ...) {
+augment.fixest <- function(x, data = NULL, newdata = NULL,
+    type.predict = c("link", "response"),
+    type.residuals = c("response", "deviance", "pearson", "working"),
+    ...) {
   if (!x$method %in% c("feols", "feglm", "femlm")) {
     stop("augment is only supported for fixest models estimated with ",
       "feols, feglm, or femlm\n",
       "  (supplied model used ", x$method, ")"
     )
   }
+  type.predict <- match.arg(type.predict)
+  type.residuals <- match.arg(type.residuals)
 
   if (is.null(newdata)) {
     df <- data
@@ -163,13 +114,11 @@ augment.fixest <- function(x, data = NULL, newdata = NULL,
   df <- as_augment_tibble(df)
   if (is.null(newdata)) {
     # use existing data
-    df <- mutate(df,
-      .fitted = predict(x, type = type.predict),
-      .resid = residuals(x)
-    )
+    df$.fitted <- predict(x, type = type.predict)
+    df$.resid <- residuals(x, type = type.residuals)
   } else {
-    #
-    df$.fitted <- residuals(x, type = type.predict, newdata = newdata)
+    # With new data, only provide predictions
+    df$.fitted <- predict(x, type = type.predict, newdata = newdata)
   }
   df
 }
@@ -179,8 +128,10 @@ augment.fixest <- function(x, data = NULL, newdata = NULL,
 #'
 #' @inherit tidy.fixest params examples
 #'
-#' @note The columns of the result depend on the type of model estimated.
-#'
+#' @note All columns listed below will be returned, but some will be `NA`,
+#' depending on the type of model estimated. `sigma`, `r.squared`,
+#' `adj.r.squared`, and `within.r.squared` will be NA for any model other than
+#' `feols`. `pseudo.r.squared` will be NA for `feols`.
 #' @evalRd return_glance(
 #'   "r.squared",
 #'   "adj.r.squared",
